@@ -39,6 +39,6 @@ if __name__ == "__main__":
         
     with open(output_file, "w") as f:
         json.dump(result, f)
-        output_file.flush()
+        f.flush()
         
     sys.exit(0)
\ No newline at end of file
